@@ -13,6 +13,8 @@ import six
 import sys
 import socket
 
+import evalidate
+
 from operator import itemgetter
 
 import okerrclient
@@ -365,7 +367,7 @@ class TaskSeq():
             msg+='\n'
             return msg
 
-        
+    
         chapters={}
         
         for code in cls.tp:
@@ -524,6 +526,40 @@ TaskMyName('OK',TaskSeq)
 TaskMyName('ERR',TaskSeq)
 
 
+class TaskEval(GenTaskProcessor):
+    parse_args=False
+    store_argline='expr'
+    
+    defargs= { 'expr': ''}
+
+    help = 'Safe evaluate pythonic expression'
+
+    def run(self,ts,data,args):
+        try:
+            node = evalidate.evalidate(args['expr'])
+            code = compile(node,'<usercode>','eval')            
+        except (ValueError, SyntaxError) as e:
+            #print(str(e))
+            # raise OkerrBadMethod('Error in filter expression: {}'.format(e))
+            ts.oc.log.error('Error in filter expression: {}'.format(e))            
+            ts.stop()
+            return None
+        
+        vv = ts.getvars()
+        vv['_data']=data
+
+        r = eval(code, {}, vv)
+        
+        if isinstance(r,bool):
+            if r:
+                return "OK"
+            else:
+                return "ERR"
+        else:
+            return r
+
+
+TaskEval('EVAL',TaskSeq)
 
 class TaskExcept(GenTaskProcessor):
     help = 'Data to use in case or exception'
